# PortfolioResponse


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**portfolio_id** | **str** | Unique ID of the portfolio | 
**portfolio_name** | **str** | Unique name of the portfolio | 
**created_at** | **datetime** | Date and time of portfolio creation (UTC) | 
**updated_at** | **datetime** | Date and time portfolio was updated (UTC) | 
**status** | **str** | Current status of the portfolio (regarding physical risk exposure dataset generation) | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


